/****************************************************************************
** Meta object code from reading C++ file 'deepinwmfaker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dbus/deepinwmfaker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'deepinwmfaker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DeepinWMFakerE_t {};
} // unnamed namespace

template <> constexpr inline auto DeepinWMFaker::qt_create_metaobjectdata<qt_meta_tag_ZN13DeepinWMFakerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeepinWMFaker",
        "WorkspaceBackgroundChanged",
        "",
        "index",
        "newUri",
        "WorkspaceBackgroundChangedForMonitor",
        "strMonitorName",
        "WorkspaceSwitched",
        "from",
        "to",
        "wmCompositingEnabledChanged",
        "compositingEnabled",
        "compositingEnabledChanged",
        "workspaceCountChanged",
        "count",
        "desktopStatusChanged",
        "BeginToMoveActiveWindowChanged",
        "SwitchApplicationChanged",
        "backward",
        "TileActiveWindowChanged",
        "side",
        "ToggleActiveWindowMaximizeChanged",
        "MaximizeActiveWindowChanged",
        "UnMaximizeActiveWindowChanged",
        "ShowAllWindowChanged",
        "ShowWindowChanged",
        "ShowWorkspaceChanged",
        "ResumeCompositorChanged",
        "reason",
        "SuspendCompositorChanged",
        "DecorationThemeChanged",
        "handleThemeChanged",
        "key",
        "value",
        "handleWorkspaceCountChanged",
        "GetWorkspaceBackground",
        "SetWorkspaceBackground",
        "uri",
        "GetCurrentWorkspaceBackground",
        "SetCurrentWorkspaceBackground",
        "GetWorkspaceBackgroundForMonitor",
        "SetWorkspaceBackgroundForMonitor",
        "GetCurrentWorkspaceBackgroundForMonitor",
        "SetCurrentWorkspaceBackgroundForMonitor",
        "SetTransientBackground",
        "SetTransientBackgroundForMonitor",
        "ChangeCurrentWorkspaceBackground",
        "GetCurrentWorkspaceInner",
        "GetCurrentWorkspace",
        "WorkspaceCount",
        "SetCurrentWorkspace",
        "NextWorkspace",
        "PreviousWorkspace",
        "SwitchToWorkspace",
        "PresentWindows",
        "QList<uint>",
        "xids",
        "EnableZoneDetected",
        "enabled",
        "GetAllAccels",
        "GetAccel",
        "id",
        "GetDefaultAccel",
        "SetAccel",
        "data",
        "RemoveAccel",
        "PreviewWindow",
        "xid",
        "CancelPreviewWindow",
        "PerformAction",
        "type",
        "BeginToMoveActiveWindow",
        "SwitchApplication",
        "TileActiveWindow",
        "ToggleActiveWindowMaximize",
        "MinimizeActiveWindow",
        "MaximizeActiveWindow",
        "UnMaximizeActiveWindow",
        "SetDecorationTheme",
        "name",
        "SetDecorationDeepinTheme",
        "setCompositingEnabled",
        "on",
        "enableEffect",
        "ShowAllWindow",
        "ShowWindow",
        "ShowWorkspace",
        "setZoneEnabled",
        "zoneEnabled",
        "setCursorTheme",
        "cursorTheme",
        "setCursorSize",
        "cursorSize",
        "GetMultiTaskingStatus",
        "SetMultiTaskingStatus",
        "isActive",
        "SlotUpdateMultitaskStatus",
        "GetIsShowDesktop",
        "SetShowDesktop",
        "isShowDesktop",
        "onGsettingsDDEAppearanceChanged",
        "compositingAllowSwitch",
        "compositingPossible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'WorkspaceBackgroundChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'WorkspaceBackgroundChangedForMonitor'
        QtMocHelpers::SignalData<void(int, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 6 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'WorkspaceSwitched'
        QtMocHelpers::SignalData<void(int, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'wmCompositingEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'compositingEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'workspaceCountChanged'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Signal 'desktopStatusChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BeginToMoveActiveWindowChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SwitchApplicationChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'TileActiveWindowChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'ToggleActiveWindowMaximizeChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaximizeActiveWindowChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UnMaximizeActiveWindowChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowAllWindowChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowWindowChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResumeCompositorChanged'
        QtMocHelpers::SignalData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'SuspendCompositorChanged'
        QtMocHelpers::SignalData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'DecorationThemeChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleThemeChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
        }}),
        // Slot 'handleWorkspaceCountChanged'
        QtMocHelpers::SlotData<void(quint32)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Slot 'GetWorkspaceBackground'
        QtMocHelpers::SlotData<QString(const int) const>(35, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'SetWorkspaceBackground'
        QtMocHelpers::SlotData<void(const int, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'GetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<QString() const>(38, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'SetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'GetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(const int, const QString &) const>(40, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'SetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const int, const QString &, const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 6 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'GetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(const QString &)>(42, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'SetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'SetTransientBackground'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'SetTransientBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'ChangeCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'GetCurrentWorkspaceInner'
        QtMocHelpers::SlotData<int() const>(47, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'GetCurrentWorkspace'
        QtMocHelpers::SlotData<int() const>(48, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'WorkspaceCount'
        QtMocHelpers::SlotData<int() const>(49, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'SetCurrentWorkspace'
        QtMocHelpers::SlotData<void(const int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'NextWorkspace'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PreviousWorkspace'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SwitchToWorkspace'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'PresentWindows'
        QtMocHelpers::SlotData<void(const QList<uint> &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'EnableZoneDetected'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'GetAllAccels'
        QtMocHelpers::SlotData<QString() const>(59, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'GetAccel'
        QtMocHelpers::SlotData<QStringList(const QString &) const>(60, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'GetDefaultAccel'
        QtMocHelpers::SlotData<QStringList(const QString &) const>(62, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'SetAccel'
        QtMocHelpers::SlotData<bool(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 64 },
        }}),
        // Slot 'RemoveAccel'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'PreviewWindow'
        QtMocHelpers::SlotData<void(uint)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 67 },
        }}),
        // Slot 'CancelPreviewWindow'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PerformAction'
        QtMocHelpers::SlotData<void(int)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 70 },
        }}),
        // Slot 'BeginToMoveActiveWindow'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SwitchApplication'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'TileActiveWindow'
        QtMocHelpers::SlotData<void(uint)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
        // Slot 'ToggleActiveWindowMaximize'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'MinimizeActiveWindow'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'MaximizeActiveWindow'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'UnMaximizeActiveWindow'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetDecorationTheme'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 70 }, { QMetaType::QString, 79 },
        }}),
        // Slot 'SetDecorationDeepinTheme'
        QtMocHelpers::SlotData<void(const QString &)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 79 },
        }}),
        // Slot 'setCompositingEnabled'
        QtMocHelpers::SlotData<void(bool)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 82 },
        }}),
        // Slot 'enableEffect'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 82 },
        }}),
        // Slot 'ShowAllWindow'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ShowWindow'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ShowWorkspace'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setZoneEnabled'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 88 },
        }}),
        // Slot 'setCursorTheme'
        QtMocHelpers::SlotData<void(QString)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 90 },
        }}),
        // Slot 'setCursorSize'
        QtMocHelpers::SlotData<void(int)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 92 },
        }}),
        // Slot 'GetMultiTaskingStatus'
        QtMocHelpers::SlotData<bool()>(93, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'SetMultiTaskingStatus'
        QtMocHelpers::SlotData<void(bool)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 95 },
        }}),
        // Slot 'SlotUpdateMultitaskStatus'
        QtMocHelpers::SlotData<void(bool)>(96, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 95 },
        }}),
        // Slot 'GetIsShowDesktop'
        QtMocHelpers::SlotData<bool()>(97, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'SetShowDesktop'
        QtMocHelpers::SlotData<void(bool)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 99 },
        }}),
        // Slot 'onGsettingsDDEAppearanceChanged'
        QtMocHelpers::SlotData<void(const QString &)>(100, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'compositingEnabled'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'compositingAllowSwitch'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final),
        // property 'compositingPossible'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'zoneEnabled'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cursorTheme'
        QtMocHelpers::PropertyData<QString>(90, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cursorSize'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeepinWMFaker, qt_meta_tag_ZN13DeepinWMFakerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DeepinWMFaker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeepinWMFakerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeepinWMFakerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DeepinWMFakerE_t>.metaTypes,
    nullptr
} };

void DeepinWMFaker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeepinWMFaker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->WorkspaceBackgroundChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->WorkspaceBackgroundChangedForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->WorkspaceSwitched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->wmCompositingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->compositingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->workspaceCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->desktopStatusChanged(); break;
        case 7: _t->BeginToMoveActiveWindowChanged(); break;
        case 8: _t->SwitchApplicationChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->TileActiveWindowChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->ToggleActiveWindowMaximizeChanged(); break;
        case 11: _t->MaximizeActiveWindowChanged(); break;
        case 12: _t->UnMaximizeActiveWindowChanged(); break;
        case 13: _t->ShowAllWindowChanged(); break;
        case 14: _t->ShowWindowChanged(); break;
        case 15: _t->ShowWorkspaceChanged(); break;
        case 16: _t->ResumeCompositorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->SuspendCompositorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->DecorationThemeChanged(); break;
        case 19: _t->handleThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->handleWorkspaceCountChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 21: { QString _r = _t->GetWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->SetWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: { QString _r = _t->GetCurrentWorkspaceBackground();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->SetCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: { QString _r = _t->GetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->SetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 27: { QString _r = _t->GetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->SetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 29: _t->SetTransientBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->SetTransientBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 31: _t->ChangeCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: { int _r = _t->GetCurrentWorkspaceInner();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 33: { int _r = _t->GetCurrentWorkspace();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: { int _r = _t->WorkspaceCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->SetCurrentWorkspace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->NextWorkspace(); break;
        case 37: _t->PreviousWorkspace(); break;
        case 38: _t->SwitchToWorkspace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->PresentWindows((*reinterpret_cast<std::add_pointer_t<QList<uint>>>(_a[1]))); break;
        case 40: _t->EnableZoneDetected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: { QString _r = _t->GetAllAccels();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: { QStringList _r = _t->GetAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 43: { QStringList _r = _t->GetDefaultAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->SetAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->RemoveAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->PreviewWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 47: _t->CancelPreviewWindow(); break;
        case 48: _t->PerformAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->BeginToMoveActiveWindow(); break;
        case 50: _t->SwitchApplication((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: _t->TileActiveWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 52: _t->ToggleActiveWindowMaximize(); break;
        case 53: _t->MinimizeActiveWindow(); break;
        case 54: _t->MaximizeActiveWindow(); break;
        case 55: _t->UnMaximizeActiveWindow(); break;
        case 56: _t->SetDecorationTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 57: _t->SetDecorationDeepinTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 58: _t->setCompositingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->enableEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->ShowAllWindow(); break;
        case 61: _t->ShowWindow(); break;
        case 62: _t->ShowWorkspace(); break;
        case 63: _t->setZoneEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: _t->setCursorTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 65: _t->setCursorSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 66: { bool _r = _t->GetMultiTaskingStatus();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 67: _t->SetMultiTaskingStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 68: _t->SlotUpdateMultitaskStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 69: { bool _r = _t->GetIsShowDesktop();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 70: _t->SetShowDesktop((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 71: _t->onGsettingsDDEAppearanceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<uint> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int , const QString & )>(_a, &DeepinWMFaker::WorkspaceBackgroundChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int , const QString & , const QString & )>(_a, &DeepinWMFaker::WorkspaceBackgroundChangedForMonitor, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int , int )>(_a, &DeepinWMFaker::WorkspaceSwitched, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(bool )>(_a, &DeepinWMFaker::wmCompositingEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(bool )>(_a, &DeepinWMFaker::compositingEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int )>(_a, &DeepinWMFaker::workspaceCountChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::desktopStatusChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::BeginToMoveActiveWindowChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(bool )>(_a, &DeepinWMFaker::SwitchApplicationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int )>(_a, &DeepinWMFaker::TileActiveWindowChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::ToggleActiveWindowMaximizeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::MaximizeActiveWindowChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::UnMaximizeActiveWindowChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::ShowAllWindowChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::ShowWindowChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::ShowWorkspaceChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int )>(_a, &DeepinWMFaker::ResumeCompositorChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)(int )>(_a, &DeepinWMFaker::SuspendCompositorChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeepinWMFaker::*)()>(_a, &DeepinWMFaker::DecorationThemeChanged, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->compositingEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->compositingAllowSwitch(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->compositingPossible(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->zoneEnabled(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->cursorSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCompositingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setZoneEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setCursorTheme(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setCursorSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeepinWMFaker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeepinWMFaker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeepinWMFakerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int DeepinWMFaker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 72)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 72;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 72)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 72;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DeepinWMFaker::WorkspaceBackgroundChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DeepinWMFaker::WorkspaceBackgroundChangedForMonitor(int _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void DeepinWMFaker::WorkspaceSwitched(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void DeepinWMFaker::wmCompositingEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeepinWMFaker::compositingEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeepinWMFaker::workspaceCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeepinWMFaker::desktopStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DeepinWMFaker::BeginToMoveActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DeepinWMFaker::SwitchApplicationChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DeepinWMFaker::TileActiveWindowChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DeepinWMFaker::ToggleActiveWindowMaximizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DeepinWMFaker::MaximizeActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DeepinWMFaker::UnMaximizeActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DeepinWMFaker::ShowAllWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DeepinWMFaker::ShowWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DeepinWMFaker::ShowWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DeepinWMFaker::ResumeCompositorChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DeepinWMFaker::SuspendCompositorChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DeepinWMFaker::DecorationThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
