/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Appearance1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "appearance1adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Appearance1Adaptor
 */

Appearance1Adaptor::Appearance1Adaptor(Appearance1 *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Appearance1Adaptor::~Appearance1Adaptor()
{
    // destructor
}

QString Appearance1Adaptor::background() const
{
    // get the value of property Background
    return qvariant_cast< QString >(parent()->property("Background"));
}

int Appearance1Adaptor::cursorSize() const
{
    // get the value of property CursorSize
    return qvariant_cast< int >(parent()->property("CursorSize"));
}

void Appearance1Adaptor::setCursorSize(int value)
{
    // set the value of property CursorSize
    parent()->setProperty("CursorSize", QVariant::fromValue(value));
}

QString Appearance1Adaptor::cursorTheme() const
{
    // get the value of property CursorTheme
    return qvariant_cast< QString >(parent()->property("CursorTheme"));
}

int Appearance1Adaptor::dTKSizeMode() const
{
    // get the value of property DTKSizeMode
    return qvariant_cast< int >(parent()->property("DTKSizeMode"));
}

void Appearance1Adaptor::setDTKSizeMode(int value)
{
    // set the value of property DTKSizeMode
    parent()->setProperty("DTKSizeMode", QVariant::fromValue(value));
}

double Appearance1Adaptor::fontSize() const
{
    // get the value of property FontSize
    return qvariant_cast< double >(parent()->property("FontSize"));
}

void Appearance1Adaptor::setFontSize(double value)
{
    // set the value of property FontSize
    parent()->setProperty("FontSize", QVariant::fromValue(value));
}

QString Appearance1Adaptor::globalTheme() const
{
    // get the value of property GlobalTheme
    return qvariant_cast< QString >(parent()->property("GlobalTheme"));
}

QString Appearance1Adaptor::gtkTheme() const
{
    // get the value of property GtkTheme
    return qvariant_cast< QString >(parent()->property("GtkTheme"));
}

QString Appearance1Adaptor::iconTheme() const
{
    // get the value of property IconTheme
    return qvariant_cast< QString >(parent()->property("IconTheme"));
}

QString Appearance1Adaptor::monospaceFont() const
{
    // get the value of property MonospaceFont
    return qvariant_cast< QString >(parent()->property("MonospaceFont"));
}

double Appearance1Adaptor::opacity() const
{
    // get the value of property Opacity
    return qvariant_cast< double >(parent()->property("Opacity"));
}

void Appearance1Adaptor::setOpacity(double value)
{
    // set the value of property Opacity
    parent()->setProperty("Opacity", QVariant::fromValue(value));
}

QString Appearance1Adaptor::qtActiveColor() const
{
    // get the value of property QtActiveColor
    return qvariant_cast< QString >(parent()->property("QtActiveColor"));
}

void Appearance1Adaptor::setQtActiveColor(const QString &value)
{
    // set the value of property QtActiveColor
    parent()->setProperty("QtActiveColor", QVariant::fromValue(value));
}

int Appearance1Adaptor::qtScrollBarPolicy() const
{
    // get the value of property QtScrollBarPolicy
    return qvariant_cast< int >(parent()->property("QtScrollBarPolicy"));
}

void Appearance1Adaptor::setQtScrollBarPolicy(int value)
{
    // set the value of property QtScrollBarPolicy
    parent()->setProperty("QtScrollBarPolicy", QVariant::fromValue(value));
}

QString Appearance1Adaptor::standardFont() const
{
    // get the value of property StandardFont
    return qvariant_cast< QString >(parent()->property("StandardFont"));
}

QString Appearance1Adaptor::wallpaperSlideShow() const
{
    // get the value of property WallpaperSlideShow
    return qvariant_cast< QString >(parent()->property("WallpaperSlideShow"));
}

void Appearance1Adaptor::setWallpaperSlideShow(const QString &value)
{
    // set the value of property WallpaperSlideShow
    parent()->setProperty("WallpaperSlideShow", QVariant::fromValue(value));
}

QString Appearance1Adaptor::wallpaperURls() const
{
    // get the value of property WallpaperURls
    return qvariant_cast< QString >(parent()->property("WallpaperURls"));
}

int Appearance1Adaptor::windowRadius() const
{
    // get the value of property WindowRadius
    return qvariant_cast< int >(parent()->property("WindowRadius"));
}

void Appearance1Adaptor::setWindowRadius(int value)
{
    // set the value of property WindowRadius
    parent()->setProperty("WindowRadius", QVariant::fromValue(value));
}

void Appearance1Adaptor::Delete(const QString &ty, const QString &name)
{
    // handle method call org.deepin.dde.Appearance1.Delete
    parent()->Delete(ty, name);
}

QString Appearance1Adaptor::GetActiveColors()
{
    // handle method call org.deepin.dde.Appearance1.GetActiveColors
    return parent()->GetActiveColors();
}

QString Appearance1Adaptor::GetCurrentWorkspaceBackground()
{
    // handle method call org.deepin.dde.Appearance1.GetCurrentWorkspaceBackground
    return parent()->GetCurrentWorkspaceBackground();
}

QString Appearance1Adaptor::GetCurrentWorkspaceBackgroundForMonitor(const QString &strMonitorName)
{
    // handle method call org.deepin.dde.Appearance1.GetCurrentWorkspaceBackgroundForMonitor
    return parent()->GetCurrentWorkspaceBackgroundForMonitor(strMonitorName);
}

double Appearance1Adaptor::GetScaleFactor()
{
    // handle method call org.deepin.dde.Appearance1.GetScaleFactor
    return parent()->GetScaleFactor();
}

ScaleFactors Appearance1Adaptor::GetScreenScaleFactors()
{
    // handle method call org.deepin.dde.Appearance1.GetScreenScaleFactors
    return parent()->GetScreenScaleFactors();
}

QString Appearance1Adaptor::GetWallpaperSlideShow(const QString &monitorName)
{
    // handle method call org.deepin.dde.Appearance1.GetWallpaperSlideShow
    return parent()->GetWallpaperSlideShow(monitorName);
}

QString Appearance1Adaptor::GetWorkspaceBackgroundForMonitor(int index, const QString &strMonitorName)
{
    // handle method call org.deepin.dde.Appearance1.GetWorkspaceBackgroundForMonitor
    return parent()->GetWorkspaceBackgroundForMonitor(index, strMonitorName);
}

QString Appearance1Adaptor::List(const QString &ty)
{
    // handle method call org.deepin.dde.Appearance1.List
    return parent()->List(ty);
}

void Appearance1Adaptor::Reset()
{
    // handle method call org.deepin.dde.Appearance1.Reset
    parent()->Reset();
}

void Appearance1Adaptor::Set(const QString &ty, const QString &value)
{
    // handle method call org.deepin.dde.Appearance1.Set
    parent()->Set(ty, value);
}

void Appearance1Adaptor::SetActiveColors(const QString &activeColors)
{
    // handle method call org.deepin.dde.Appearance1.SetActiveColors
    parent()->SetActiveColors(activeColors);
}

void Appearance1Adaptor::SetCurrentWorkspaceBackground(const QString &uri)
{
    // handle method call org.deepin.dde.Appearance1.SetCurrentWorkspaceBackground
    parent()->SetCurrentWorkspaceBackground(uri);
}

void Appearance1Adaptor::SetCurrentWorkspaceBackgroundForMonitor(const QString &uri, const QString &strMonitorName)
{
    // handle method call org.deepin.dde.Appearance1.SetCurrentWorkspaceBackgroundForMonitor
    parent()->SetCurrentWorkspaceBackgroundForMonitor(uri, strMonitorName);
}

void Appearance1Adaptor::SetMonitorBackground(const QString &monitorName, const QString &imageGile)
{
    // handle method call org.deepin.dde.Appearance1.SetMonitorBackground
    parent()->SetMonitorBackground(monitorName, imageGile);
}

void Appearance1Adaptor::SetScaleFactor(double scale)
{
    // handle method call org.deepin.dde.Appearance1.SetScaleFactor
    parent()->SetScaleFactor(scale);
}

void Appearance1Adaptor::SetScreenScaleFactors(ScaleFactors scaleFactor)
{
    // handle method call org.deepin.dde.Appearance1.SetScreenScaleFactors
    parent()->SetScreenScaleFactors(scaleFactor);
}

void Appearance1Adaptor::SetWallpaperSlideShow(const QString &monitorName, const QString &slideShow)
{
    // handle method call org.deepin.dde.Appearance1.SetWallpaperSlideShow
    parent()->SetWallpaperSlideShow(monitorName, slideShow);
}

void Appearance1Adaptor::SetWorkspaceBackgroundForMonitor(int index, const QString &strMonitorName, const QString &uri)
{
    // handle method call org.deepin.dde.Appearance1.SetWorkspaceBackgroundForMonitor
    parent()->SetWorkspaceBackgroundForMonitor(index, strMonitorName, uri);
}

QString Appearance1Adaptor::Show(const QString &ty, const QStringList &names)
{
    // handle method call org.deepin.dde.Appearance1.Show
    return parent()->Show(ty, names);
}

QString Appearance1Adaptor::Thumbnail(const QString &ty, const QString &name)
{
    // handle method call org.deepin.dde.Appearance1.Thumbnail
    return parent()->Thumbnail(ty, name);
}


#include "moc_appearance1adaptor.cpp"
