/****************************************************************************
** Meta object code from reading C++ file 'appearance1thread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dbus/appearance1thread.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearance1thread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17Appearance1ThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto Appearance1Thread::qt_create_metaobjectdata<qt_meta_tag_ZN17Appearance1ThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Appearance1Thread",
        "Changed",
        "",
        "ty",
        "value",
        "Refreshed",
        "type",
        "setFontSize",
        "setOpacity",
        "setQtActiveColor",
        "setWallpaperSlideShow",
        "setWindowRadius",
        "setDTKSizeMode",
        "setQtScrollBarPolicy",
        "setCursorSize",
        "Delete",
        "name",
        "QDBusMessage",
        "message",
        "GetCurrentWorkspaceBackground",
        "GetCurrentWorkspaceBackgroundForMonitor",
        "strMonitorName",
        "GetScaleFactor",
        "GetScreenScaleFactors",
        "ScaleFactors",
        "GetActiveColors",
        "GetWallpaperSlideShow",
        "monitorName",
        "GetWorkspaceBackgroundForMonitor",
        "index",
        "List",
        "Reset",
        "Set",
        "SetCurrentWorkspaceBackground",
        "uri",
        "SetCurrentWorkspaceBackgroundForMonitor",
        "SetMonitorBackground",
        "imageGile",
        "SetScaleFactor",
        "scale",
        "SetScreenScaleFactors",
        "scaleFactors",
        "SetActiveColors",
        "activeColors",
        "SetWallpaperSlideShow",
        "slideShow",
        "SetWorkspaceBackgroundForMonitor",
        "Show",
        "names",
        "Thumbnail",
        "init",
        "Background",
        "CursorTheme",
        "FontSize",
        "GlobalTheme",
        "GtkTheme",
        "IconTheme",
        "MonospaceFont",
        "Opacity",
        "QtActiveColor",
        "StandardFont",
        "WallpaperSlideShow",
        "WallpaperURls",
        "WindowRadius",
        "DTKSizeMode",
        "qtScrollBarPolicy",
        "CursorSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'Refreshed'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setFontSize'
        QtMocHelpers::SlotData<void(double)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'setOpacity'
        QtMocHelpers::SlotData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'setQtActiveColor'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'setWallpaperSlideShow'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'setWindowRadius'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setDTKSizeMode'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setQtScrollBarPolicy'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'setCursorSize'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusMessage &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<QString(const QDBusMessage &)>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(const QString &, const QDBusMessage &)>(20, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetScaleFactor'
        QtMocHelpers::SlotData<double(const QDBusMessage &)>(22, 2, QMC::AccessPublic, QMetaType::Double, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetScreenScaleFactors'
        QtMocHelpers::SlotData<ScaleFactors(const QDBusMessage &)>(23, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetActiveColors'
        QtMocHelpers::SlotData<QString(const QDBusMessage &)>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetWallpaperSlideShow'
        QtMocHelpers::SlotData<QString(const QString &, const QDBusMessage &)>(26, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 27 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'GetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(const int &, const QString &, const QDBusMessage &)>(28, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 21 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<QString(const QString &, const QDBusMessage &)>(30, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'Reset'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'Set'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusMessage &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &, const QDBusMessage &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusMessage &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QString, 21 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetMonitorBackground'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusMessage &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 37 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetScaleFactor'
        QtMocHelpers::SlotData<void(double, const QDBusMessage &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 39 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetScreenScaleFactors'
        QtMocHelpers::SlotData<void(ScaleFactors, const QDBusMessage &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 41 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetActiveColors'
        QtMocHelpers::SlotData<void(const QString &, const QDBusMessage &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetWallpaperSlideShow'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusMessage &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 45 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'SetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const int &, const QString &, const QString &, const QDBusMessage &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 21 }, { QMetaType::QString, 34 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<QString(const QString &, const QStringList &, const QDBusMessage &)>(47, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { QMetaType::QStringList, 48 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'Thumbnail'
        QtMocHelpers::SlotData<QString(const QString &, const QString &, const QDBusMessage &)>(49, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Background'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'CursorTheme'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'FontSize'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'GlobalTheme'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'GtkTheme'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IconTheme'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MonospaceFont'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Opacity'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'QtActiveColor'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'StandardFont'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WallpaperSlideShow'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WallpaperURls'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WindowRadius'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'DTKSizeMode'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'qtScrollBarPolicy'
        QtMocHelpers::PropertyData<int>(65, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'CursorSize'
        QtMocHelpers::PropertyData<int>(66, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Appearance1Thread, qt_meta_tag_ZN17Appearance1ThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Appearance1Thread::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17Appearance1ThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17Appearance1ThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17Appearance1ThreadE_t>.metaTypes,
    nullptr
} };

void Appearance1Thread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Appearance1Thread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->Refreshed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setFontSize((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->setOpacity((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->setQtActiveColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setWindowRadius((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setDTKSizeMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setQtScrollBarPolicy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setCursorSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->Delete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 11: { QString _r = _t->GetCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->GetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { double _r = _t->GetScaleFactor((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 14: { ScaleFactors _r = _t->GetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ScaleFactors*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->GetActiveColors((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->GetWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->GetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->Reset((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 20: _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 21: _t->SetCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 22: _t->SetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 23: _t->SetMonitorBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 24: _t->SetScaleFactor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 25: _t->SetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<ScaleFactors>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 26: _t->SetActiveColors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 27: _t->SetWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 28: _t->SetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[4]))); break;
        case 29: { QString _r = _t->Show((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->Thumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->init(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Appearance1Thread::*)(const QString & , const QString & )>(_a, &Appearance1Thread::Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Appearance1Thread::*)(const QString & )>(_a, &Appearance1Thread::Refreshed, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->background(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->fontSize(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->globalTheme(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->gtkTheme(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->iconTheme(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->monospaceFont(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->qtActiveColor(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->standardFont(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->wallpaperSlideShow(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->wallpaperURls(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->dtkSizeMode(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->qtScrollBarPolicy(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->cursorSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setFontSize(*reinterpret_cast<double*>(_v)); break;
        case 7: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 8: _t->setQtActiveColor(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setWallpaperSlideShow(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setDTKSizeMode(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setQtScrollBarPolicy(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setCursorSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Appearance1Thread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Appearance1Thread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17Appearance1ThreadE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Appearance1Thread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Appearance1Thread::Changed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Appearance1Thread::Refreshed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
