/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was com.deepin.wm.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "wmadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class WmAdaptor
 */

WmAdaptor::WmAdaptor(DeepinWMFaker *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

WmAdaptor::~WmAdaptor()
{
    // destructor
}

bool WmAdaptor::compositingAllowSwitch() const
{
    // get the value of property compositingAllowSwitch
    return qvariant_cast< bool >(parent()->property("compositingAllowSwitch"));
}

bool WmAdaptor::compositingEnabled() const
{
    // get the value of property compositingEnabled
    return qvariant_cast< bool >(parent()->property("compositingEnabled"));
}

void WmAdaptor::setCompositingEnabled(bool value)
{
    // set the value of property compositingEnabled
    parent()->setProperty("compositingEnabled", QVariant::fromValue(value));
}

bool WmAdaptor::compositingPossible() const
{
    // get the value of property compositingPossible
    return qvariant_cast< bool >(parent()->property("compositingPossible"));
}

int WmAdaptor::cursorSize() const
{
    // get the value of property cursorSize
    return qvariant_cast< int >(parent()->property("cursorSize"));
}

void WmAdaptor::setCursorSize(int value)
{
    // set the value of property cursorSize
    parent()->setProperty("cursorSize", QVariant::fromValue(value));
}

QString WmAdaptor::cursorTheme() const
{
    // get the value of property cursorTheme
    return qvariant_cast< QString >(parent()->property("cursorTheme"));
}

void WmAdaptor::setCursorTheme(const QString &value)
{
    // set the value of property cursorTheme
    parent()->setProperty("cursorTheme", QVariant::fromValue(value));
}

bool WmAdaptor::zoneEnabled() const
{
    // get the value of property zoneEnabled
    return qvariant_cast< bool >(parent()->property("zoneEnabled"));
}

void WmAdaptor::setZoneEnabled(bool value)
{
    // set the value of property zoneEnabled
    parent()->setProperty("zoneEnabled", QVariant::fromValue(value));
}

void WmAdaptor::BeginToMoveActiveWindow()
{
    // handle method call com.deepin.wm.BeginToMoveActiveWindow
    parent()->BeginToMoveActiveWindow();
}

void WmAdaptor::CancelPreviewWindow()
{
    // handle method call com.deepin.wm.CancelPreviewWindow
    parent()->CancelPreviewWindow();
}

void WmAdaptor::ChangeCurrentWorkspaceBackground(const QString &uri)
{
    // handle method call com.deepin.wm.ChangeCurrentWorkspaceBackground
    parent()->ChangeCurrentWorkspaceBackground(uri);
}

void WmAdaptor::EnableZoneDetected(bool enabled)
{
    // handle method call com.deepin.wm.EnableZoneDetected
    parent()->EnableZoneDetected(enabled);
}

QStringList WmAdaptor::GetAccel(const QString &id)
{
    // handle method call com.deepin.wm.GetAccel
    return parent()->GetAccel(id);
}

QString WmAdaptor::GetAllAccels()
{
    // handle method call com.deepin.wm.GetAllAccels
    return parent()->GetAllAccels();
}

int WmAdaptor::GetCurrentWorkspace()
{
    // handle method call com.deepin.wm.GetCurrentWorkspace
    return parent()->GetCurrentWorkspace();
}

QString WmAdaptor::GetCurrentWorkspaceBackground()
{
    // handle method call com.deepin.wm.GetCurrentWorkspaceBackground
    return parent()->GetCurrentWorkspaceBackground();
}

QString WmAdaptor::GetCurrentWorkspaceBackgroundForMonitor(const QString &strMonitorName)
{
    // handle method call com.deepin.wm.GetCurrentWorkspaceBackgroundForMonitor
    return parent()->GetCurrentWorkspaceBackgroundForMonitor(strMonitorName);
}

QStringList WmAdaptor::GetDefaultAccel(const QString &id)
{
    // handle method call com.deepin.wm.GetDefaultAccel
    return parent()->GetDefaultAccel(id);
}

bool WmAdaptor::GetIsShowDesktop()
{
    // handle method call com.deepin.wm.GetIsShowDesktop
    return parent()->GetIsShowDesktop();
}

bool WmAdaptor::GetMultiTaskingStatus()
{
    // handle method call com.deepin.wm.GetMultiTaskingStatus
    return parent()->GetMultiTaskingStatus();
}

QString WmAdaptor::GetWorkspaceBackground(int index)
{
    // handle method call com.deepin.wm.GetWorkspaceBackground
    return parent()->GetWorkspaceBackground(index);
}

QString WmAdaptor::GetWorkspaceBackgroundForMonitor(int index, const QString &strMonitorName)
{
    // handle method call com.deepin.wm.GetWorkspaceBackgroundForMonitor
    return parent()->GetWorkspaceBackgroundForMonitor(index, strMonitorName);
}

void WmAdaptor::MaximizeActiveWindow()
{
    // handle method call com.deepin.wm.MaximizeActiveWindow
    parent()->MaximizeActiveWindow();
}

void WmAdaptor::MinimizeActiveWindow()
{
    // handle method call com.deepin.wm.MinimizeActiveWindow
    parent()->MinimizeActiveWindow();
}

void WmAdaptor::NextWorkspace()
{
    // handle method call com.deepin.wm.NextWorkspace
    parent()->NextWorkspace();
}

void WmAdaptor::PerformAction(int type)
{
    // handle method call com.deepin.wm.PerformAction
    parent()->PerformAction(type);
}

void WmAdaptor::PresentWindows(const QList<uint> &xids)
{
    // handle method call com.deepin.wm.PresentWindows
    parent()->PresentWindows(xids);
}

void WmAdaptor::PreviewWindow(uint xid)
{
    // handle method call com.deepin.wm.PreviewWindow
    parent()->PreviewWindow(xid);
}

void WmAdaptor::PreviousWorkspace()
{
    // handle method call com.deepin.wm.PreviousWorkspace
    parent()->PreviousWorkspace();
}

void WmAdaptor::RemoveAccel(const QString &id)
{
    // handle method call com.deepin.wm.RemoveAccel
    parent()->RemoveAccel(id);
}

bool WmAdaptor::SetAccel(const QString &data)
{
    // handle method call com.deepin.wm.SetAccel
    return parent()->SetAccel(data);
}

void WmAdaptor::SetCurrentWorkspace(int index)
{
    // handle method call com.deepin.wm.SetCurrentWorkspace
    parent()->SetCurrentWorkspace(index);
}

void WmAdaptor::SetCurrentWorkspaceBackground(const QString &uri)
{
    // handle method call com.deepin.wm.SetCurrentWorkspaceBackground
    parent()->SetCurrentWorkspaceBackground(uri);
}

void WmAdaptor::SetCurrentWorkspaceBackgroundForMonitor(const QString &uri, const QString &strMonitorName)
{
    // handle method call com.deepin.wm.SetCurrentWorkspaceBackgroundForMonitor
    parent()->SetCurrentWorkspaceBackgroundForMonitor(uri, strMonitorName);
}

void WmAdaptor::SetDecorationDeepinTheme(const QString &deepinThemeName)
{
    // handle method call com.deepin.wm.SetDecorationDeepinTheme
    parent()->SetDecorationDeepinTheme(deepinThemeName);
}

void WmAdaptor::SetDecorationTheme(const QString &themeType, const QString &themeName)
{
    // handle method call com.deepin.wm.SetDecorationTheme
    parent()->SetDecorationTheme(themeType, themeName);
}

void WmAdaptor::SetMultiTaskingStatus(bool isActive)
{
    // handle method call com.deepin.wm.SetMultiTaskingStatus
    parent()->SetMultiTaskingStatus(isActive);
}

void WmAdaptor::SetShowDesktop(bool isShowDesktop)
{
    // handle method call com.deepin.wm.SetShowDesktop
    parent()->SetShowDesktop(isShowDesktop);
}

void WmAdaptor::SetTransientBackground(const QString &in0)
{
    // handle method call com.deepin.wm.SetTransientBackground
    parent()->SetTransientBackground(in0);
}

void WmAdaptor::SetTransientBackgroundForMonitor(const QString &uri, const QString &strMonitorName)
{
    // handle method call com.deepin.wm.SetTransientBackgroundForMonitor
    parent()->SetTransientBackgroundForMonitor(uri, strMonitorName);
}

void WmAdaptor::SetWorkspaceBackground(int index, const QString &uri)
{
    // handle method call com.deepin.wm.SetWorkspaceBackground
    parent()->SetWorkspaceBackground(index, uri);
}

void WmAdaptor::SetWorkspaceBackgroundForMonitor(int index, const QString &strMonitorName, const QString &uri)
{
    // handle method call com.deepin.wm.SetWorkspaceBackgroundForMonitor
    parent()->SetWorkspaceBackgroundForMonitor(index, strMonitorName, uri);
}

void WmAdaptor::ShowAllWindow()
{
    // handle method call com.deepin.wm.ShowAllWindow
    parent()->ShowAllWindow();
}

void WmAdaptor::ShowWindow()
{
    // handle method call com.deepin.wm.ShowWindow
    parent()->ShowWindow();
}

void WmAdaptor::ShowWorkspace()
{
    // handle method call com.deepin.wm.ShowWorkspace
    parent()->ShowWorkspace();
}

void WmAdaptor::SwitchApplication(bool backward)
{
    // handle method call com.deepin.wm.SwitchApplication
    parent()->SwitchApplication(backward);
}

void WmAdaptor::SwitchToWorkspace(bool backward)
{
    // handle method call com.deepin.wm.SwitchToWorkspace
    parent()->SwitchToWorkspace(backward);
}

void WmAdaptor::TileActiveWindow(uint side)
{
    // handle method call com.deepin.wm.TileActiveWindow
    parent()->TileActiveWindow(side);
}

void WmAdaptor::ToggleActiveWindowMaximize()
{
    // handle method call com.deepin.wm.ToggleActiveWindowMaximize
    parent()->ToggleActiveWindowMaximize();
}

void WmAdaptor::UnMaximizeActiveWindow()
{
    // handle method call com.deepin.wm.UnMaximizeActiveWindow
    parent()->UnMaximizeActiveWindow();
}

int WmAdaptor::WorkspaceCount()
{
    // handle method call com.deepin.wm.WorkspaceCount
    return parent()->WorkspaceCount();
}


#include "moc_wmadaptor.cpp"
