/****************************************************************************
** Meta object code from reading C++ file 'appearance1adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "appearance1adaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearance1adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18Appearance1AdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Appearance1Adaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18Appearance1AdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Appearance1Adaptor",
        "D-Bus Interface",
        "org.deepin.dde.Appearance1",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.dde.Appearance1\">\n    <method nam"
        "e=\"Delete\">\n      <arg direction=\"in\" type=\"s\" name=\"ty\"/"
        ">\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n    </m"
        "ethod>\n    <method name=\"GetScaleFactor\">\n      <arg direction"
        "=\"out\" type=\"d\" name=\"scaleFactor\"/>\n    </method>\n    <me"
        "thod name=\"GetScreenScaleFactors\">\n      <arg direction=\"out\""
        " type=\"a{sd}\" name=\"scaleFactor\"/>\n      <annotation value=\""
        "ScaleFactors\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n  "
        "  </method>\n    <method name=\"GetWallpaperSlideShow\">\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"monitorName\"/>\n      <arg "
        "direction=\"out\" type=\"s\" name=\"slideShow\"/>\n    </method>\n"
        "    <method name=\"List\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"ty\"/>\n      <arg direction=\"out\" type=\"s\" name=\"lis"
        "t\"/>\n    </method>\n    <method name=\"Reset\"/>\n    <method na"
        "me=\"Set\">\n      <arg direction=\"in\" type=\"s\" name=\"ty\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n    </met"
        "hod>\n    <method name=\"SetMonitorBackground\">\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"monitorName\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"imageGile\"/>\n    </method>\n    <meth"
        "od name=\"SetScaleFactor\">\n      <arg direction=\"in\" type=\"d\""
        " name=\"scale\"/>\n    </method>\n    <method name=\"SetScreenScal"
        "eFactors\">\n      <arg direction=\"in\" type=\"a{sd}\" name=\"sca"
        "leFactor\"/>\n      <annotation value=\"ScaleFactors\" name=\"org."
        "qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <method na"
        "me=\"SetWallpaperSlideShow\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"monitorName\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"slideShow\"/>\n    </method>\n    <method name=\"Show\">\n"
        "      <arg direction=\"in\" type=\"s\" name=\"ty\"/>\n      <arg d"
        "irection=\"in\" type=\"as\" name=\"names\"/>\n      <arg direction"
        "=\"out\" type=\"s\" name=\"detail\"/>\n    </method>\n    <method "
        "name=\"Thumbnail\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "ty\"/>\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n  "
        "    <arg direction=\"out\" type=\"s\" name=\"file\"/>\n    </metho"
        "d>\n    <method name=\"SetCurrentWorkspaceBackground\">\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"uri\"/>\n    </method>\n    <"
        "method name=\"GetCurrentWorkspaceBackground\">\n      <arg directi"
        "on=\"out\" type=\"s\" name=\"uri\"/>\n    </method>\n    <method n"
        "ame=\"SetCurrentWorkspaceBackgroundForMonitor\">\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"uri\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"strMonitorName\"/>\n    </method>\n    <method "
        "name=\"GetCurrentWorkspaceBackgroundForMonitor\">\n      <arg dire"
        "ction=\"in\" type=\"s\" name=\"strMonitorName\"/>\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"uri\"/>\n    </method>\n    <metho"
        "d name=\"SetWorkspaceBackgroundForMonitor\">\n      <arg direction"
        "=\"in\" type=\"i\" name=\"index\"/>\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"strMonitorName\"/>\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"uri\"/>\n    </method>\n    <method name=\"GetWor"
        "kspaceBackgroundForMonitor\">\n      <arg direction=\"in\" type=\""
        "i\" name=\"index\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"strMonitorName\"/>\n      <arg direction=\"out\" type=\"s\" name"
        "=\"uri\"/>\n    </method>\n    <method name=\"SetActiveColors\">\n"
        "      <arg direction=\"in\" type=\"s\" name=\"activeColors\"/>\n  "
        "  </method>\n    <method name=\"GetActiveColors\">\n      <arg dir"
        "ection=\"out\" type=\"s\" name=\"activeColors\"/>\n    </method>\n"
        "    <property access=\"readwrite\" type=\"d\" name=\"FontSize\"/>\n"
        "    <property access=\"readwrite\" type=\"d\" name=\"Opacity\"/>\n"
        "    <property access=\"readwrite\" type=\"i\" name=\"WindowRadius\""
        "/>\n    <property access=\"read\" type=\"s\" name=\"Background\"/>"
        "\n    <property access=\"read\" type=\"s\" name=\"GlobalTheme\"/>\n"
        "    <property access=\"read\" type=\"s\" name=\"GtkTheme\"/>\n    "
        "<property access=\"read\" type=\"s\" name=\"IconTheme\"/>\n    <pr"
        "operty access=\"read\" type=\"s\" name=\"CursorTheme\"/>\n    <pro"
        "perty access=\"read\" type=\"s\" name=\"MonospaceFont\"/>\n    <pr"
        "operty access=\"readwrite\" type=\"s\" name=\"QtActiveColor\"/>\n "
        "   <property access=\"read\" type=\"s\" name=\"StandardFont\"/>\n "
        "   <property access=\"readwrite\" type=\"s\" name=\"WallpaperSlide"
        "Show\"/>\n    <property access=\"readwrite\" type=\"i\" name=\"DTK"
        "SizeMode\"/>\n    <property access=\"readwrite\" type=\"i\" name=\""
        "QtScrollBarPolicy\"/>\n    <property access=\"readwrite\" type=\"i"
        "\" name=\"CursorSize\"/>\n    <property access=\"read\" type=\"s\""
        " name=\"WallpaperURls\"/>\n    <signal name=\"Changed\">\n      <a"
        "rg type=\"s\" name=\"ty\"/>\n      <arg type=\"s\" name=\"value\"/"
        ">\n    </signal>\n    <signal name=\"Refreshed\">\n      <arg type"
        "=\"s\" name=\"type\"/>\n    </signal>\n  </interface>\n",
        "Changed",
        "",
        "ty",
        "value",
        "Refreshed",
        "type",
        "Delete",
        "name",
        "GetActiveColors",
        "GetCurrentWorkspaceBackground",
        "GetCurrentWorkspaceBackgroundForMonitor",
        "strMonitorName",
        "GetScaleFactor",
        "GetScreenScaleFactors",
        "ScaleFactors",
        "GetWallpaperSlideShow",
        "monitorName",
        "GetWorkspaceBackgroundForMonitor",
        "index",
        "List",
        "Reset",
        "Set",
        "SetActiveColors",
        "activeColors",
        "SetCurrentWorkspaceBackground",
        "uri",
        "SetCurrentWorkspaceBackgroundForMonitor",
        "SetMonitorBackground",
        "imageGile",
        "SetScaleFactor",
        "scale",
        "SetScreenScaleFactors",
        "scaleFactor",
        "SetWallpaperSlideShow",
        "slideShow",
        "SetWorkspaceBackgroundForMonitor",
        "Show",
        "names",
        "Thumbnail",
        "Background",
        "CursorSize",
        "CursorTheme",
        "DTKSizeMode",
        "FontSize",
        "GlobalTheme",
        "GtkTheme",
        "IconTheme",
        "MonospaceFont",
        "Opacity",
        "QtActiveColor",
        "QtScrollBarPolicy",
        "StandardFont",
        "WallpaperSlideShow",
        "WallpaperURls",
        "WindowRadius"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'Refreshed'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'GetActiveColors'
        QtMocHelpers::SlotData<QString()>(13, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'GetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<QString()>(14, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'GetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'GetScaleFactor'
        QtMocHelpers::SlotData<double()>(17, 6, QMC::AccessPublic, QMetaType::Double),
        // Slot 'GetScreenScaleFactors'
        QtMocHelpers::SlotData<ScaleFactors()>(18, 6, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'GetWallpaperSlideShow'
        QtMocHelpers::SlotData<QString(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'GetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(int, const QString &)>(22, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 23 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<QString(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'Reset'
        QtMocHelpers::SlotData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Set'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'SetActiveColors'
        QtMocHelpers::SlotData<void(const QString &)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'SetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'SetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'SetMonitorBackground'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 33 },
        }}),
        // Slot 'SetScaleFactor'
        QtMocHelpers::SlotData<void(double)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 35 },
        }}),
        // Slot 'SetScreenScaleFactors'
        QtMocHelpers::SlotData<void(ScaleFactors)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 37 },
        }}),
        // Slot 'SetWallpaperSlideShow'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'SetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(int, const QString &, const QString &)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::QString, 16 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<QString(const QString &, const QStringList &)>(41, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 42 },
        }}),
        // Slot 'Thumbnail'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(43, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Background'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'CursorSize'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'CursorTheme'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'DTKSizeMode'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'FontSize'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'GlobalTheme'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'GtkTheme'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IconTheme'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MonospaceFont'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Opacity'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'QtActiveColor'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'QtScrollBarPolicy'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'StandardFont'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WallpaperSlideShow'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WallpaperURls'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WindowRadius'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Appearance1Adaptor, qt_meta_tag_ZN18Appearance1AdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Appearance1Adaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18Appearance1AdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18Appearance1AdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18Appearance1AdaptorE_t>.metaTypes,
    nullptr
} };

void Appearance1Adaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Appearance1Adaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->Refreshed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->Delete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: { QString _r = _t->GetActiveColors();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->GetCurrentWorkspaceBackground();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->GetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { double _r = _t->GetScaleFactor();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 7: { ScaleFactors _r = _t->GetScreenScaleFactors();
            if (_a[0]) *reinterpret_cast<ScaleFactors*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->GetWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->GetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->Reset(); break;
        case 12: _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->SetActiveColors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->SetCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->SetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->SetMonitorBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->SetScaleFactor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->SetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<ScaleFactors>>(_a[1]))); break;
        case 19: _t->SetWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->SetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 21: { QString _r = _t->Show((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->Thumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Appearance1Adaptor::*)(const QString & , const QString & )>(_a, &Appearance1Adaptor::Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Appearance1Adaptor::*)(const QString & )>(_a, &Appearance1Adaptor::Refreshed, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->background(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->cursorSize(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->dTKSizeMode(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->fontSize(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->globalTheme(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->gtkTheme(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->iconTheme(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->monospaceFont(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->qtActiveColor(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->qtScrollBarPolicy(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->standardFont(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->wallpaperSlideShow(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->wallpaperURls(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCursorSize(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setDTKSizeMode(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setFontSize(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 10: _t->setQtActiveColor(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setQtScrollBarPolicy(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setWallpaperSlideShow(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Appearance1Adaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Appearance1Adaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18Appearance1AdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Appearance1Adaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Appearance1Adaptor::Changed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Appearance1Adaptor::Refreshed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
