/****************************************************************************
** Meta object code from reading C++ file 'wmadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "wmadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wmadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9WmAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto WmAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN9WmAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WmAdaptor",
        "D-Bus Interface",
        "com.deepin.wm",
        "D-Bus Introspection",
        "  <interface name=\"com.deepin.wm\">\n    <property access=\"readw"
        "rite\" type=\"b\" name=\"compositingEnabled\"/>\n    <property acc"
        "ess=\"read\" type=\"b\" name=\"compositingPossible\"/>\n    <prope"
        "rty access=\"read\" type=\"b\" name=\"compositingAllowSwitch\"/>\n"
        "    <property access=\"readwrite\" type=\"b\" name=\"zoneEnabled\""
        "/>\n    <property access=\"readwrite\" type=\"s\" name=\"cursorThe"
        "me\"/>\n    <property access=\"readwrite\" type=\"i\" name=\"curso"
        "rSize\"/>\n    <method name=\"SwitchApplication\">\n      <arg dir"
        "ection=\"in\" type=\"b\" name=\"backward\"/>\n    </method>\n    <"
        "method name=\"TileActiveWindow\">\n      <arg direction=\"in\" typ"
        "e=\"u\" name=\"side\"/>\n    </method>\n    <method name=\"BeginTo"
        "MoveActiveWindow\"/>\n    <method name=\"ToggleActiveWindowMaximiz"
        "e\"/>\n    <method name=\"MinimizeActiveWindow\"/>\n    <method na"
        "me=\"MaximizeActiveWindow\"/>\n    <method name=\"UnMaximizeActive"
        "Window\"/>\n    <method name=\"ShowWorkspace\"/>\n    <method name"
        "=\"ShowWindow\"/>\n    <method name=\"ShowAllWindow\"/>\n    <meth"
        "od name=\"PerformAction\">\n      <arg direction=\"in\" type=\"i\""
        " name=\"type\"/>\n    </method>\n    <method name=\"PreviewWindow\""
        ">\n      <arg direction=\"in\" type=\"u\" name=\"xid\"/>\n    </me"
        "thod>\n    <method name=\"CancelPreviewWindow\"/>\n    <method nam"
        "e=\"GetCurrentWorkspaceBackground\">\n      <arg direction=\"out\""
        " type=\"s\" name=\"result\"/>\n    </method>\n    <method name=\"S"
        "etCurrentWorkspaceBackground\">\n      <arg direction=\"in\" type="
        "\"s\" name=\"uri\"/>\n    </method>\n    <method name=\"GetWorkspa"
        "ceBackground\">\n      <arg direction=\"in\" type=\"i\" name=\"ind"
        "ex\"/>\n      <arg direction=\"out\" type=\"s\" name=\"result\"/>\n"
        "    </method>\n    <method name=\"SetWorkspaceBackground\">\n     "
        " <arg direction=\"in\" type=\"i\" name=\"index\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"uri\"/>\n    </method>\n    <metho"
        "d name=\"SetTransientBackground\">\n      <arg direction=\"in\" ty"
        "pe=\"s\"/>\n    </method>\n    <method name=\"GetCurrentWorkspaceB"
        "ackgroundForMonitor\">\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"strMonitorName\"/>\n      <arg direction=\"out\" type=\"s\" na"
        "me=\"result\"/>\n    </method>\n    <method name=\"SetCurrentWorks"
        "paceBackgroundForMonitor\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"uri\"/>\n      <arg direction=\"in\" type=\"s\" name=\"str"
        "MonitorName\"/>\n    </method>\n    <method name=\"GetWorkspaceBac"
        "kgroundForMonitor\">\n      <arg direction=\"in\" type=\"i\" name="
        "\"index\"/>\n      <arg direction=\"in\" type=\"s\" name=\"strMoni"
        "torName\"/>\n      <arg direction=\"out\" type=\"s\" name=\"result"
        "\"/>\n    </method>\n    <method name=\"SetWorkspaceBackgroundForM"
        "onitor\">\n      <arg direction=\"in\" type=\"i\" name=\"index\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"strMonitorName\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n    </met"
        "hod>\n    <method name=\"SetTransientBackgroundForMonitor\">\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n      <arg dire"
        "ction=\"in\" type=\"s\" name=\"strMonitorName\"/>\n    </method>\n"
        "    <method name=\"GetCurrentWorkspace\">\n      <arg direction=\""
        "out\" type=\"i\" name=\"index\"/>\n    </method>\n    <method name"
        "=\"WorkspaceCount\">\n      <arg direction=\"out\" type=\"i\" name"
        "=\"count\"/>\n    </method>\n    <method name=\"SetCurrentWorkspac"
        "e\">\n      <arg direction=\"in\" type=\"i\" name=\"index\"/>\n   "
        " </method>\n    <method name=\"PreviousWorkspace\"/>\n    <method "
        "name=\"NextWorkspace\"/>\n    <method name=\"GetAllAccels\">\n    "
        "  <arg direction=\"out\" type=\"s\" name=\"data\"/>\n    </method>"
        "\n    <method name=\"GetAccel\">\n      <arg direction=\"in\" type"
        "=\"s\" name=\"id\"/>\n      <arg direction=\"out\" type=\"as\" nam"
        "e=\"data\"/>\n    </method>\n    <method name=\"GetDefaultAccel\">"
        "\n      <arg direction=\"in\" type=\"s\" name=\"id\"/>\n      <arg"
        " direction=\"out\" type=\"as\" name=\"data\"/>\n    </method>\n   "
        " <method name=\"SetAccel\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"data\"/>\n      <arg direction=\"out\" type=\"b\" name=\"r"
        "esult\"/>\n    </method>\n    <method name=\"RemoveAccel\">\n     "
        " <arg direction=\"in\" type=\"s\" name=\"id\"/>\n    </method>\n  "
        "  <method name=\"SetDecorationTheme\">\n      <arg direction=\"in\""
        " type=\"s\" name=\"themeType\"/>\n      <arg direction=\"in\" type"
        "=\"s\" name=\"themeName\"/>\n    </method>\n    <signal name=\"Dec"
        "orationThemeChanged\"/>\n    <method name=\"SetDecorationDeepinThe"
        "me\">\n      <arg direction=\"in\" type=\"s\" name=\"deepinThemeNa"
        "me\"/>\n    </method>\n    <signal name=\"WorkspaceBackgroundChang"
        "ed\">\n      <arg type=\"i\" name=\"index\"/>\n      <arg type=\"s"
        "\" name=\"newUri\"/>\n    </signal>\n    <signal name=\"WorkspaceB"
        "ackgroundChangedForMonitor\">\n      <arg type=\"i\" name=\"index\""
        "/>\n      <arg type=\"s\" name=\"strMonitorName\"/>\n      <arg ty"
        "pe=\"s\" name=\"uri\"/>\n    </signal>\n    <signal name=\"composi"
        "tingEnabledChanged\">\n      <arg type=\"b\" name=\"enabled\"/>\n "
        "   </signal>\n    <signal name=\"wmCompositingEnabledChanged\">\n "
        "     <arg type=\"b\" name=\"enabled\"/>\n    </signal>\n    <signa"
        "l name=\"workspaceCountChanged\">\n      <arg type=\"i\" name=\"co"
        "unt\"/>\n    </signal>\n    <signal name=\"BeginToMoveActiveWindow"
        "Changed\"/>\n    <signal name=\"SwitchApplicationChanged\">\n     "
        " <arg type=\"b\" name=\"backward\"/>\n    </signal>\n    <signal n"
        "ame=\"TileActiveWindowChanged\">\n      <arg type=\"i\" name=\"sid"
        "e\"/>\n    </signal>\n    <signal name=\"ToggleActiveWindowMaximiz"
        "eChanged\"/>\n    <signal name=\"MaximizeActiveWindowChanged\"/>\n"
        "    <signal name=\"UnMaximizeActiveWindowChanged\"/>\n    <signal "
        "name=\"ShowAllWindowChanged\"/>\n    <signal name=\"ShowWindowChan"
        "ged\"/>\n    <signal name=\"ShowWorkspaceChanged\"/>\n    <signal "
        "name=\"ResumeCompositorChanged\">\n      <arg type=\"i\" name=\"re"
        "ason\"/>\n    </signal>\n    <signal name=\"SuspendCompositorChang"
        "ed\">\n      <arg type=\"i\" name=\"reason\"/>\n    </signal>\n   "
        " <method name=\"ChangeCurrentWorkspaceBackground\">\n      <arg di"
        "rection=\"in\" type=\"s\" name=\"uri\"/>\n    </method>\n    <meth"
        "od name=\"SwitchToWorkspace\">\n      <arg direction=\"in\" type=\""
        "b\" name=\"backward\"/>\n    </method>\n    <method name=\"Present"
        "Windows\">\n      <arg direction=\"in\" type=\"au\" name=\"xids\"/"
        ">\n      <annotation value=\"QList&lt;uint&gt;\" name=\"org.qtproj"
        "ect.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <method name=\"E"
        "nableZoneDetected\">\n      <arg direction=\"in\" type=\"b\" name="
        "\"enabled\"/>\n    </method>\n    <signal name=\"WorkspaceSwitched"
        "\">\n      <arg type=\"i\" name=\"from\"/>\n      <arg type=\"i\" "
        "name=\"to\"/>\n    </signal>\n    <method name=\"GetMultiTaskingSt"
        "atus\">\n      <arg direction=\"out\" type=\"b\" name=\"isActive\""
        "/>\n    </method>\n    <method name=\"SetMultiTaskingStatus\">\n  "
        "    <arg direction=\"in\" type=\"b\" name=\"isActive\"/>\n    </me"
        "thod>\n    <method name=\"GetIsShowDesktop\">\n      <arg directio"
        "n=\"out\" type=\"b\" name=\"isShowDesktop\"/>\n    </method>\n    "
        "<method name=\"SetShowDesktop\">\n      <arg direction=\"in\" type"
        "=\"b\" name=\"isShowDesktop\"/>\n    </method>\n  </interface>\n",
        "BeginToMoveActiveWindowChanged",
        "",
        "DecorationThemeChanged",
        "MaximizeActiveWindowChanged",
        "ResumeCompositorChanged",
        "reason",
        "ShowAllWindowChanged",
        "ShowWindowChanged",
        "ShowWorkspaceChanged",
        "SuspendCompositorChanged",
        "SwitchApplicationChanged",
        "backward",
        "TileActiveWindowChanged",
        "side",
        "ToggleActiveWindowMaximizeChanged",
        "UnMaximizeActiveWindowChanged",
        "WorkspaceBackgroundChanged",
        "index",
        "newUri",
        "WorkspaceBackgroundChangedForMonitor",
        "strMonitorName",
        "uri",
        "WorkspaceSwitched",
        "from",
        "to",
        "compositingEnabledChanged",
        "enabled",
        "wmCompositingEnabledChanged",
        "workspaceCountChanged",
        "count",
        "BeginToMoveActiveWindow",
        "CancelPreviewWindow",
        "ChangeCurrentWorkspaceBackground",
        "EnableZoneDetected",
        "GetAccel",
        "id",
        "GetAllAccels",
        "GetCurrentWorkspace",
        "GetCurrentWorkspaceBackground",
        "GetCurrentWorkspaceBackgroundForMonitor",
        "GetDefaultAccel",
        "GetIsShowDesktop",
        "GetMultiTaskingStatus",
        "GetWorkspaceBackground",
        "GetWorkspaceBackgroundForMonitor",
        "MaximizeActiveWindow",
        "MinimizeActiveWindow",
        "NextWorkspace",
        "PerformAction",
        "type",
        "PresentWindows",
        "QList<uint>",
        "xids",
        "PreviewWindow",
        "xid",
        "PreviousWorkspace",
        "RemoveAccel",
        "SetAccel",
        "data",
        "SetCurrentWorkspace",
        "SetCurrentWorkspaceBackground",
        "SetCurrentWorkspaceBackgroundForMonitor",
        "SetDecorationDeepinTheme",
        "deepinThemeName",
        "SetDecorationTheme",
        "themeType",
        "themeName",
        "SetMultiTaskingStatus",
        "isActive",
        "SetShowDesktop",
        "isShowDesktop",
        "SetTransientBackground",
        "in0",
        "SetTransientBackgroundForMonitor",
        "SetWorkspaceBackground",
        "SetWorkspaceBackgroundForMonitor",
        "ShowAllWindow",
        "ShowWindow",
        "ShowWorkspace",
        "SwitchApplication",
        "SwitchToWorkspace",
        "TileActiveWindow",
        "ToggleActiveWindowMaximize",
        "UnMaximizeActiveWindow",
        "WorkspaceCount",
        "compositingAllowSwitch",
        "compositingEnabled",
        "compositingPossible",
        "cursorSize",
        "cursorTheme",
        "zoneEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BeginToMoveActiveWindowChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DecorationThemeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaximizeActiveWindowChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ResumeCompositorChanged'
        QtMocHelpers::SignalData<void(int)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'ShowAllWindowChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowWindowChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SuspendCompositorChanged'
        QtMocHelpers::SignalData<void(int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'SwitchApplicationChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'TileActiveWindowChanged'
        QtMocHelpers::SignalData<void(int)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Signal 'ToggleActiveWindowMaximizeChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UnMaximizeActiveWindowChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WorkspaceBackgroundChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'WorkspaceBackgroundChangedForMonitor'
        QtMocHelpers::SignalData<void(int, const QString &, const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Signal 'WorkspaceSwitched'
        QtMocHelpers::SignalData<void(int, int)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Int, 29 },
        }}),
        // Signal 'compositingEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'wmCompositingEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'workspaceCountChanged'
        QtMocHelpers::SignalData<void(int)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'BeginToMoveActiveWindow'
        QtMocHelpers::SlotData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CancelPreviewWindow'
        QtMocHelpers::SlotData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ChangeCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'EnableZoneDetected'
        QtMocHelpers::SlotData<void(bool)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'GetAccel'
        QtMocHelpers::SlotData<QStringList(const QString &)>(39, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'GetAllAccels'
        QtMocHelpers::SlotData<QString()>(41, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'GetCurrentWorkspace'
        QtMocHelpers::SlotData<int()>(42, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'GetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<QString()>(43, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'GetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(const QString &)>(44, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'GetDefaultAccel'
        QtMocHelpers::SlotData<QStringList(const QString &)>(45, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'GetIsShowDesktop'
        QtMocHelpers::SlotData<bool()>(46, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetMultiTaskingStatus'
        QtMocHelpers::SlotData<bool()>(47, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetWorkspaceBackground'
        QtMocHelpers::SlotData<QString(int)>(48, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'GetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(int, const QString &)>(49, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'MaximizeActiveWindow'
        QtMocHelpers::SlotData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'MinimizeActiveWindow'
        QtMocHelpers::SlotData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'NextWorkspace'
        QtMocHelpers::SlotData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PerformAction'
        QtMocHelpers::SlotData<void(int)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 54 },
        }}),
        // Slot 'PresentWindows'
        QtMocHelpers::SlotData<void(const QList<uint> &)>(55, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'PreviewWindow'
        QtMocHelpers::SlotData<void(uint)>(58, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 59 },
        }}),
        // Slot 'PreviousWorkspace'
        QtMocHelpers::SlotData<void()>(60, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RemoveAccel'
        QtMocHelpers::SlotData<void(const QString &)>(61, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'SetAccel'
        QtMocHelpers::SlotData<bool(const QString &)>(62, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 63 },
        }}),
        // Slot 'SetCurrentWorkspace'
        QtMocHelpers::SlotData<void(int)>(64, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'SetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &)>(65, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'SetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(66, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'SetDecorationDeepinTheme'
        QtMocHelpers::SlotData<void(const QString &)>(67, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'SetDecorationTheme'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(69, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 70 }, { QMetaType::QString, 71 },
        }}),
        // Slot 'SetMultiTaskingStatus'
        QtMocHelpers::SlotData<void(bool)>(72, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 73 },
        }}),
        // Slot 'SetShowDesktop'
        QtMocHelpers::SlotData<void(bool)>(74, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 75 },
        }}),
        // Slot 'SetTransientBackground'
        QtMocHelpers::SlotData<void(const QString &)>(76, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 77 },
        }}),
        // Slot 'SetTransientBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(78, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'SetWorkspaceBackground'
        QtMocHelpers::SlotData<void(int, const QString &)>(79, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'SetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(int, const QString &, const QString &)>(80, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'ShowAllWindow'
        QtMocHelpers::SlotData<void()>(81, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ShowWindow'
        QtMocHelpers::SlotData<void()>(82, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ShowWorkspace'
        QtMocHelpers::SlotData<void()>(83, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SwitchApplication'
        QtMocHelpers::SlotData<void(bool)>(84, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'SwitchToWorkspace'
        QtMocHelpers::SlotData<void(bool)>(85, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'TileActiveWindow'
        QtMocHelpers::SlotData<void(uint)>(86, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 18 },
        }}),
        // Slot 'ToggleActiveWindowMaximize'
        QtMocHelpers::SlotData<void()>(87, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'UnMaximizeActiveWindow'
        QtMocHelpers::SlotData<void()>(88, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'WorkspaceCount'
        QtMocHelpers::SlotData<int()>(89, 6, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'compositingAllowSwitch'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'compositingEnabled'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'compositingPossible'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'cursorSize'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cursorTheme'
        QtMocHelpers::PropertyData<QString>(94, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'zoneEnabled'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<WmAdaptor, qt_meta_tag_ZN9WmAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WmAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9WmAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9WmAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9WmAdaptorE_t>.metaTypes,
    nullptr
} };

void WmAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WmAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BeginToMoveActiveWindowChanged(); break;
        case 1: _t->DecorationThemeChanged(); break;
        case 2: _t->MaximizeActiveWindowChanged(); break;
        case 3: _t->ResumeCompositorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->ShowAllWindowChanged(); break;
        case 5: _t->ShowWindowChanged(); break;
        case 6: _t->ShowWorkspaceChanged(); break;
        case 7: _t->SuspendCompositorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->SwitchApplicationChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->TileActiveWindowChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->ToggleActiveWindowMaximizeChanged(); break;
        case 11: _t->UnMaximizeActiveWindowChanged(); break;
        case 12: _t->WorkspaceBackgroundChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->WorkspaceBackgroundChangedForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->WorkspaceSwitched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->compositingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->wmCompositingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->workspaceCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->BeginToMoveActiveWindow(); break;
        case 19: _t->CancelPreviewWindow(); break;
        case 20: _t->ChangeCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->EnableZoneDetected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: { QStringList _r = _t->GetAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->GetAllAccels();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->GetCurrentWorkspace();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { QString _r = _t->GetCurrentWorkspaceBackground();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: { QString _r = _t->GetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: { QStringList _r = _t->GetDefaultAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->GetIsShowDesktop();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->GetMultiTaskingStatus();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->GetWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { QString _r = _t->GetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->MaximizeActiveWindow(); break;
        case 33: _t->MinimizeActiveWindow(); break;
        case 34: _t->NextWorkspace(); break;
        case 35: _t->PerformAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->PresentWindows((*reinterpret_cast<std::add_pointer_t<QList<uint>>>(_a[1]))); break;
        case 37: _t->PreviewWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 38: _t->PreviousWorkspace(); break;
        case 39: _t->RemoveAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: { bool _r = _t->SetAccel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->SetCurrentWorkspace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->SetCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->SetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 44: _t->SetDecorationDeepinTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 45: _t->SetDecorationTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 46: _t->SetMultiTaskingStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->SetShowDesktop((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->SetTransientBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->SetTransientBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 50: _t->SetWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 51: _t->SetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 52: _t->ShowAllWindow(); break;
        case 53: _t->ShowWindow(); break;
        case 54: _t->ShowWorkspace(); break;
        case 55: _t->SwitchApplication((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 56: _t->SwitchToWorkspace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: _t->TileActiveWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 58: _t->ToggleActiveWindowMaximize(); break;
        case 59: _t->UnMaximizeActiveWindow(); break;
        case 60: { int _r = _t->WorkspaceCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<uint> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::BeginToMoveActiveWindowChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::DecorationThemeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::MaximizeActiveWindowChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int )>(_a, &WmAdaptor::ResumeCompositorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::ShowAllWindowChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::ShowWindowChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::ShowWorkspaceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int )>(_a, &WmAdaptor::SuspendCompositorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(bool )>(_a, &WmAdaptor::SwitchApplicationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int )>(_a, &WmAdaptor::TileActiveWindowChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::ToggleActiveWindowMaximizeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)()>(_a, &WmAdaptor::UnMaximizeActiveWindowChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int , const QString & )>(_a, &WmAdaptor::WorkspaceBackgroundChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int , const QString & , const QString & )>(_a, &WmAdaptor::WorkspaceBackgroundChangedForMonitor, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int , int )>(_a, &WmAdaptor::WorkspaceSwitched, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(bool )>(_a, &WmAdaptor::compositingEnabledChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(bool )>(_a, &WmAdaptor::wmCompositingEnabledChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (WmAdaptor::*)(int )>(_a, &WmAdaptor::workspaceCountChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->compositingAllowSwitch(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->compositingEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->compositingPossible(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->cursorSize(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->zoneEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCompositingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setCursorSize(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setCursorTheme(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setZoneEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WmAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WmAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9WmAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int WmAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void WmAdaptor::BeginToMoveActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WmAdaptor::DecorationThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WmAdaptor::MaximizeActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void WmAdaptor::ResumeCompositorChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WmAdaptor::ShowAllWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void WmAdaptor::ShowWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void WmAdaptor::ShowWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void WmAdaptor::SuspendCompositorChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void WmAdaptor::SwitchApplicationChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void WmAdaptor::TileActiveWindowChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void WmAdaptor::ToggleActiveWindowMaximizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void WmAdaptor::UnMaximizeActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void WmAdaptor::WorkspaceBackgroundChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void WmAdaptor::WorkspaceBackgroundChangedForMonitor(int _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void WmAdaptor::WorkspaceSwitched(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void WmAdaptor::compositingEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void WmAdaptor::wmCompositingEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void WmAdaptor::workspaceCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
