/****************************************************************************
** Meta object code from reading C++ file 'appearancedbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dbus/appearancedbusproxy.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearancedbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AppearanceDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto AppearanceDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN19AppearanceDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppearanceDBusProxy",
        "workspaceCountChanged",
        "",
        "count",
        "WorkspaceSwitched",
        "from",
        "to",
        "cursorThemeChanged",
        "cursorTheme",
        "cursorSizeChanged",
        "cursorSize",
        "PrimaryChanged",
        "Primary",
        "MonitorsChanged",
        "QList<QDBusObjectPath>",
        "monitors",
        "ConcatScreenEnabledChanged",
        "isCancat",
        "SetScaleFactorStarted",
        "SetScaleFactorDone",
        "DesktopBackgroundsChanged",
        "desktopBackgrounds",
        "GreeterBackgroundChanged",
        "greeterBackground",
        "TimezoneChanged",
        "timezone",
        "NTPChanged",
        "NTP",
        "TimeUpdate",
        "HandleForSleep",
        "sleep",
        "Notify",
        "in0",
        "in2",
        "summary",
        "body",
        "options",
        "QVariantMap",
        "optionMap",
        "expireTimeout",
        "NotifyNid",
        "id",
        "WorkspaceCount",
        "GetWorkspaceBackgroundForMonitor",
        "index",
        "strMonitorName",
        "SetCurrentWorkspaceBackgroundForMonitor",
        "uri",
        "SetDecorationDeepinTheme",
        "deepinThemeName",
        "ChangeCurrentWorkspaceBackground",
        "GetCurrentWorkspace",
        "SetWorkspaceBackgroundForMonitor",
        "ListOutputNames",
        "SetScaleFactor",
        "scale",
        "SetScreenScaleFactors",
        "ScaleFactors",
        "factors",
        "FindUserById",
        "uid",
        "SetCurrentWorkspace",
        "currentWorkspace",
        "SetDesktopBackgrounds",
        "val",
        "SetGreeterBackground",
        "bg",
        "onDisplayPropertiesChanged",
        "QDBusMessage",
        "message",
        "onNotificationClosed",
        "Monitors",
        "ConcatScreenEnabled",
        "DesktopBackgrounds",
        "GreeterBackground",
        "Timezone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'workspaceCountChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'WorkspaceSwitched'
        QtMocHelpers::SignalData<void(int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'cursorThemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'cursorSizeChanged'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'PrimaryChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'MonitorsChanged'
        QtMocHelpers::SignalData<void(QList<QDBusObjectPath>)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'ConcatScreenEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'SetScaleFactorStarted'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SetScaleFactorDone'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DesktopBackgroundsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 21 },
        }}),
        // Signal 'GreeterBackgroundChanged'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Signal 'TimezoneChanged'
        QtMocHelpers::SignalData<void(QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'NTPChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'TimeUpdate'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HandleForSleep'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'Notify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QVariantMap &, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 33 }, { QMetaType::QString, 34 }, { QMetaType::QString, 35 },
            { QMetaType::QStringList, 36 }, { 0x80000000 | 37, 38 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'NotifyNid'
        QtMocHelpers::SlotData<void(uint)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 41 },
        }}),
        // Slot 'WorkspaceCount'
        QtMocHelpers::SlotData<int()>(42, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'GetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QString(int, const QString &)>(43, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 44 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'SetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'SetDecorationDeepinTheme'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'ChangeCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<void(const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'GetCurrentWorkspace'
        QtMocHelpers::SlotData<int()>(51, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'SetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<void(int, const QString &, const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 44 }, { QMetaType::QString, 45 }, { QMetaType::QString, 47 },
        }}),
        // Slot 'ListOutputNames'
        QtMocHelpers::SlotData<QStringList()>(53, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'SetScaleFactor'
        QtMocHelpers::SlotData<void(double)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 55 },
        }}),
        // Slot 'SetScreenScaleFactors'
        QtMocHelpers::SlotData<void(const ScaleFactors &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 58 },
        }}),
        // Slot 'FindUserById'
        QtMocHelpers::SlotData<QString(const QString &)>(59, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'SetCurrentWorkspace'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 62 },
        }}),
        // Slot 'SetDesktopBackgrounds'
        QtMocHelpers::SlotData<void(const QStringList &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 64 },
        }}),
        // Slot 'SetGreeterBackground'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'onDisplayPropertiesChanged'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 68, 69 },
        }}),
        // Slot 'onNotificationClosed'
        QtMocHelpers::SlotData<void(uint, uint)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 2 }, { QMetaType::UInt, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'cursorTheme'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'cursorSize'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'Primary'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'Monitors'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(71, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'ConcatScreenEnabled'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'DesktopBackgrounds'
        QtMocHelpers::PropertyData<QStringList>(73, QMetaType::QStringList, QMC::DefaultPropertyFlags, 9),
        // property 'GreeterBackground'
        QtMocHelpers::PropertyData<QString>(74, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'Timezone'
        QtMocHelpers::PropertyData<QString>(75, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'NTP'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppearanceDBusProxy, qt_meta_tag_ZN19AppearanceDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AppearanceDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AppearanceDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AppearanceDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AppearanceDBusProxyE_t>.metaTypes,
    nullptr
} };

void AppearanceDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppearanceDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->workspaceCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->WorkspaceSwitched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->cursorThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->cursorSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->PrimaryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->MonitorsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 6: _t->ConcatScreenEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->SetScaleFactorStarted(); break;
        case 8: _t->SetScaleFactorDone(); break;
        case 9: _t->DesktopBackgroundsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 10: _t->GreeterBackgroundChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->TimezoneChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->NTPChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->TimeUpdate(); break;
        case 14: _t->HandleForSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->Notify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 16: _t->NotifyNid((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 17: { int _r = _t->WorkspaceCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->GetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->SetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->SetDecorationDeepinTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->ChangeCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: { int _r = _t->GetCurrentWorkspace();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->SetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 24: { QStringList _r = _t->ListOutputNames();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->SetScaleFactor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 26: _t->SetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<ScaleFactors>>(_a[1]))); break;
        case 27: { QString _r = _t->FindUserById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->SetCurrentWorkspace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->SetDesktopBackgrounds((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 30: _t->SetGreeterBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->onDisplayPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 32: _t->onNotificationClosed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(int )>(_a, &AppearanceDBusProxy::workspaceCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(int , int )>(_a, &AppearanceDBusProxy::WorkspaceSwitched, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(const QString & )>(_a, &AppearanceDBusProxy::cursorThemeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(int )>(_a, &AppearanceDBusProxy::cursorSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(const QString & )>(_a, &AppearanceDBusProxy::PrimaryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(QList<QDBusObjectPath> )>(_a, &AppearanceDBusProxy::MonitorsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(bool )>(_a, &AppearanceDBusProxy::ConcatScreenEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)()>(_a, &AppearanceDBusProxy::SetScaleFactorStarted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)()>(_a, &AppearanceDBusProxy::SetScaleFactorDone, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(const QStringList & )>(_a, &AppearanceDBusProxy::DesktopBackgroundsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(const QString & )>(_a, &AppearanceDBusProxy::GreeterBackgroundChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(QString )>(_a, &AppearanceDBusProxy::TimezoneChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(bool )>(_a, &AppearanceDBusProxy::NTPChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)()>(_a, &AppearanceDBusProxy::TimeUpdate, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppearanceDBusProxy::*)(bool )>(_a, &AppearanceDBusProxy::HandleForSleep, 14))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->cursorSize(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->primary(); break;
        case 3: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->monitors(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isConcatScreenEnabled(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->desktopBackgrounds(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->greeterBackground(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->timezone(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->nTP(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setcursorTheme(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setcursorSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AppearanceDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppearanceDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AppearanceDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AppearanceDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AppearanceDBusProxy::workspaceCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AppearanceDBusProxy::WorkspaceSwitched(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void AppearanceDBusProxy::cursorThemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AppearanceDBusProxy::cursorSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AppearanceDBusProxy::PrimaryChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AppearanceDBusProxy::MonitorsChanged(QList<QDBusObjectPath> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AppearanceDBusProxy::ConcatScreenEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AppearanceDBusProxy::SetScaleFactorStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AppearanceDBusProxy::SetScaleFactorDone()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AppearanceDBusProxy::DesktopBackgroundsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AppearanceDBusProxy::GreeterBackgroundChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void AppearanceDBusProxy::TimezoneChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void AppearanceDBusProxy::NTPChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void AppearanceDBusProxy::TimeUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AppearanceDBusProxy::HandleForSleep(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
